Skip to contents

This function returns a vector of the possible hector halocarbon concentrations that can be accessed with fetchvars.

Usage

ALL_HALOCARBON_CONCENTRATIONS()

Value

Character vector of variable names.

See also

Examples

if (FALSE) { # \dontrun{
ini <- system.file(package = "hector", "input/hector_ssp245.ini")
hc <- newcore(ini)
run(hc)
out <- fetchvars(core = hc, dates = 1900:2100, vars = ALL_HALOCARBON_CONCENTRATIONS())
print(out)
} # }