Skip to contents

This function returns a vector of the possible hector halocarbon constraints that can be accessed with fetchvars or set with setvar.

Usage

ALL_HALOCARBON_CONSTRAINTS()

Value

Character vector of variable names.

Examples

if (FALSE) { # \dontrun{
ini <- system.file(package = "hector", "input/hector_ssp245.ini")
hc <- newcore(ini)
run(hc)
out <- fetchvars(core = hc, dates = 1900:2100, vars = ALL_HALOCARBON_CONSTRAINTS())
print(out)
} # }