get_biome_inits.RdInternal helper function for biome functions.
get_biome_inits(core, biome)
| core | Hector core |
|---|---|
| biome | Name of biome for which to retrieve data |
Named numeric vector of biome initial conditions and parameters
Alexey Shiklomanov