getunits.RdThis function provides units only for variables that can be set in the model
using setvar. Variables read from the model with
fetchvars will have a units column in the data frame they are
returned in.
getunits(vars)
| vars | Capability strings for variables to get units for. |
|---|
Character vector of unit strings. Variables not found will have NA entries.