newcore.RdThe object returned is a handle to the newly created instance. It will be required as an argument for all functions that operate on the instance. Creating multiple instances simultaneously is supported.
newcore( inifile, loglevel = 0, suppresslogging = TRUE, name = "unnamed hector core" )
| inifile | (String) name of the hector input file. |
|---|---|
| loglevel | (int) minimum message level to output in logs (see |
| suppresslogging | (bool) If true, suppress all logging (loglevel is ignored in this case). |
| name | (string) An optional name to identify the core. |
handle for the Hector instance.