run.RdRun Hector up through the specified time. This function does not return the results
of the run. To get results, run fetch.
run(core, runtodate = -1)
| core | Handle to the Hector instance that is to be run. |
|---|---|
| runtodate | Date to run to. The default is to run to the end date configured in the input file used to initialize the core. |
The Hector instance handle